/*
 * NAME:
 *      Signal - signal() interface to sigaction()
 *
 * SYNOPSIS:
 *	extern int _SignalFlags;
 *
 *	void (*Signal(int "sig", void (*"handler")(int)))(int);
 *
 * DESCRIPTION:
 *	This routine can be used to call sigaction(2) using the
 *	arguments of signal(2).
 *
 *	The global '_SignalFlags' is used to populate the
 *	sigaction.sa_flags field and defaults to SIGNAL_FLAGS which
 *	defaults to 0 for no auto-restart on system calls.
 *
 * AUTHOR:
 *      Simon J. Gerraty <sjg@quick.com.au>
 */
/*
 *      @(#)Copyright (c) 1993,1997 Simon J. Gerraty.
 *
 *      This is free software.  It comes with NO WARRANTY.
 *      Permission to use, modify and distribute this source code
 *      is granted subject to the following conditions.
 *      1/ that the above copyright notice and this notice
 *      are preserved in all copies and that due credit be given
 *      to the author.
 *      2/ that any changes to this code are clearly commented
 *      as such so that the author does not get blamed for bugs
 *      other than his own.
 *
 *      Please send copies of changes and bug-fixes to:
 *      sjg@quick.com.au
 */
/*
 *	from: sigact.c,v 1.11 1994/01/24 22:04:28 sjg
 */
#ifndef lint
static char RCSid[] = "$Id: sig.c,v 1.8 1997/03/16 10:54:41 sjg Exp $";
#endif

#include <signal.h>
#include <sys/cdefs.h>

#ifndef SA_RESTART
# define SA_RESTART	2
#endif
#ifndef SIG_HDLR
# define SIG_HDLR void
#endif
#ifndef SIGNAL_FLAGS
# define SIGNAL_FLAGS 0		/* no auto-restart */
#endif

int     _SignalFlags = SIGNAL_FLAGS;

SIG_HDLR(*Signal(sig, handler)) __P((int))
	int     sig;
	SIG_HDLR(*handler) __P((int));
{
	struct sigaction act, oact;

	act.sa_handler = handler;
	sigemptyset(&act.sa_mask);
	act.sa_flags = _SignalFlags;
	if (sigaction(sig, &act, &oact) < 0)
		return (SIG_ERR);
	return (oact.sa_handler);
}
